# -*- coding: utf-8 -*-
#
# Copyright (c) 2007 by H. Turgut Uyar <uyar@tekir.org>
#
# This file is part of Humphrey Videotheque.
#
# Humphrey Videotheque is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Humphrey Videotheque is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

__author__ = """H. Turgut Uyar <uyar@tekir.org>"""
__docformat__ = "restructuredtext"


from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import OrderedBaseFolder
from Products.Archetypes.atapi import Schema
from Products.Archetypes.atapi import StringField, StringWidget
from Products.Archetypes.atapi import TextField, TextAreaWidget
from Products.Archetypes.atapi import SelectionWidget
from Products.ATContentTypes.content.base import ATCTMixin
from Products.ATContentTypes.content.base import registerATCT
from Products.ATContentTypes.content.schemata import ATContentTypeSchema
from Products.ATContentTypes.content.schemata import finalizeATCTSchema
from Products.Videotheque.config import PROJECTNAME
from Products.Videotheque.content.schemata import TVSystemSchema


VideoMediumSchema = ATContentTypeSchema.copy() + Schema((
    StringField(
        name="id",
        required=True,
        widget=StringWidget(
            label_msgid="label_code",
            label="Code",
            description_msgid="help_code_item",
            description="Enter a code for this collection item.",
            size=8,
            i18n_domain="videotheque"
            )
        ),
    ),)


VideoDVDSchema = VideoMediumSchema.copy() + TVSystemSchema.copy() + Schema((
    StringField(
        name="region",
        vocabulary="_getDvdRegionOptions", enforceVocabulary=True,
        widget=SelectionWidget(
            label_msgid="label_region",
            label="Region",
            description_msgid="help_region_dvd",
            description="Select the region code of this edition.",
            i18n_domain="videotheque"
            )
        ),

    TextField(
        name="extras",
        searchable=True,
        widget=TextAreaWidget(
            label_msgid="label_extras",
            label="Extras",
            description_msgid="help_extras_dvd",
            description="Enter the extras on this DVD.",
            i18n_domain="videotheque"
            )
        ),
    ),)


VideoCDSchema = VideoMediumSchema.copy() + TVSystemSchema.copy()


VideoDataDiscSchema = VideoMediumSchema.copy()


VideoTapeSchema = VideoMediumSchema.copy() + TVSystemSchema.copy() + Schema((
    StringField(
        name="tape_system",
        vocabulary="_getTapeSystemOptions", enforceVocabulary=True,
        widget=SelectionWidget(
            label_msgid="label_tape_system",
            label="Tape System",
            description_msgid="help_tape_system_copy",
            description="Select the system of this tape.",
            i18n_domain="videotheque"
            )
        ),
    ),)


finalizeATCTSchema(VideoMediumSchema, folderish=True)
finalizeATCTSchema(VideoCDSchema, folderish=True)
finalizeATCTSchema(VideoDVDSchema, folderish=True)
finalizeATCTSchema(VideoDataDiscSchema, folderish=True)
finalizeATCTSchema(VideoTapeSchema, folderish=True)


class VideoMedium(ATCTMixin, OrderedBaseFolder):
    """A medium that can contain movie copies."""

    __implements__ = (OrderedBaseFolder.__implements__,
                      ATCTMixin.__implements__)

    schema = VideoMediumSchema

    security = ClassSecurityInfo()

    security.declarePublic("_getTvSystemOptions")
    def _getTvSystemOptions(self):
        options = self.videotheque_tool.getOptions("tv_system_options")
        return tuple(options)


class VideoDVD(VideoMedium):
    """A video DVD."""

    __implements__ = (VideoMedium.__implements__,)

    schema = VideoDVDSchema

    _at_rename_after_creation = True

    security = ClassSecurityInfo()

    security.declarePublic("_getDvdRegionOptions")
    def _getDvdRegionOptions(self):
        options = self.videotheque_tool.getOptions("dvd_region_options")
        return tuple(options)


class VideoCD(VideoMedium):
    """A video CD."""

    __implements__ = (VideoMedium.__implements__,)

    schema = VideoCDSchema

    _at_rename_after_creation = True

    security = ClassSecurityInfo()


class VideoDataDisc(VideoMedium):
    """A data disc containing movie files."""

    __implements__ = (VideoMedium.__implements__,)

    schema = VideoDataDiscSchema

    _at_rename_after_creation = True

    security = ClassSecurityInfo()


class VideoTape(VideoMedium):
    """A video tape."""

    __implements__ = (VideoMedium.__implements__,)

    schema = VideoTapeSchema

    _at_rename_after_creation = True

    security = ClassSecurityInfo()

    security.declarePublic("_getTapeSystemOptions")
    def _getTapeSystemOptions(self):
        options = self.videotheque_tool.getOptions("tape_system_options")
        return tuple(options)


registerATCT(VideoDVD, PROJECTNAME)
registerATCT(VideoCD, PROJECTNAME)
registerATCT(VideoDataDisc, PROJECTNAME)
registerATCT(VideoTape, PROJECTNAME)
