# -*- coding: utf-8 -*-
#
# Copyright (c) 2007 by H. Turgut Uyar <uyar@tekir.org>
#
# This file is part of Humphrey Videotheque.
#
# Humphrey Videotheque is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Humphrey Videotheque is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

__author__ = """H. Turgut Uyar <uyar@tekir.org>"""
__docformat__ = "restructuredtext"


from AccessControl import ClassSecurityInfo
from Products.CMFCore.utils import getToolByName
from Products.Archetypes.atapi import Schema
from Products.Archetypes.atapi import StringField, StringWidget
from Products.Archetypes.atapi import IntegerField, IntegerWidget
from Products.Archetypes.atapi import FloatField, DecimalWidget
from Products.Archetypes.atapi import TextField, TextAreaWidget
from Products.Archetypes.atapi import LinesField, LinesWidget
from Products.Archetypes.atapi import MultiSelectionWidget, InAndOutWidget
from Products.Archetypes.atapi import KeywordWidget
from Products.Archetypes.atapi import ImageField, ImageWidget
from Products.ATContentTypes.content.base import ATCTContent
from Products.ATContentTypes.content.base import registerATCT
from Products.ATContentTypes.content.schemata import ATContentTypeSchema
from Products.ATContentTypes.content.schemata import finalizeATCTSchema
from Products.Videotheque.config import PROJECTNAME


MovieSchema = ATContentTypeSchema.copy() + Schema((
    StringField(
        name="imdb_id",
        widget=StringWidget(
            label_msgid="label_imdb_id",
            label="IMDB Id",
            description_msgid="help_imdb_id_movie",
            description="Enter the IMDB id of this movie. This should consist of 7 digits.",
            maxlength=7, size=7,
            i18n_domain="videotheque"
            )
        ),

    IntegerField(
        name="year",
        widget=IntegerWidget(
            label_msgid="label_year",
            label="Year",
            description_msgid="help_year_movie",
            description="Enter the year this movie was produced.",
            maxlength=4, size=4,
            i18n_domain="videotheque"
            )
        ),

    IntegerField(
        name="runtime",
        widget=IntegerWidget(
            label_msgid="label_runtime",
            label="Runtime",
            description_msgid="help_runtime_movie",
            description="Enter the runtime of this movie, in minutes.",
            maxlength=3, size=3,
            i18n_domain="videotheque"
            )
        ),

    StringField(
        name="color",
        vocabulary="_getColorOptions", enforceVocabulary=True,
        multiValued=True,
        widget=MultiSelectionWidget(
            label_msgid="label_color",
            label="Color",
            description_msgid="help_color_movie",
            description="Select the color type of this movie.",
            format="checkbox",
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="genres",
        vocabulary="_getGenreOptions", enforceVocabulary=True,
        multiValued=True,
        accessor="MovieGenre", edit_accessor="MovieGenre",
        index="KeywordIndex",
        widget=InAndOutWidget(
            label_msgid="label_genres",
            label="Genres",
            description_msgid="help_genres_movie",
            description="Select the genres of this movie.",
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="countries",
        vocabulary="_getCountryOptions", enforceVocabulary=True,
        multiValued=True,
        widget=InAndOutWidget(
            label_msgid="label_countries",
            label="Countries",
            description_msgid="help_countries_movie",
            description="Select the countries that produced this movie.",
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="langs",
        vocabulary="_getLanguageOptions", enforceVocabulary=True,
        multiValued=True,
        widget=InAndOutWidget(
            label_msgid="label_languages",
            label="Languages",
            description_msgid="help_languages_movie",
            description="Select the languages spoken in this movie.",
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="akas",
        searchable=True,
        widget=LinesWidget(
            label_msgid="label_akas",
            label="Alternative Titles",
            description_msgid="help_akas_movie",
            description="Enter the alternative titles of this movie, one on each line.",
            rows=2,
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="directors",
        #schemata="credits",
        searchable=True,
        widget=LinesWidget(
            label_msgid="label_directors",
            label="Directors",
            description_msgid="help_directors_movie",
            description="Enter the directors of this movie, one on each line.",
            rows=2,
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="cast",
        #schemata="credits",
        searchable=True,
        widget=LinesWidget(
            label_msgid="label_cast",
            label="Cast",
            description_msgid="help_cast_movie",
            description="Enter the cast of this movie, one on each line.",
            rows=5,
            i18n_domain="videotheque"
            )
        ),

    StringField(
        name="tagline",
        schemata="plot",
        searchable=True,
        widget=StringWidget(
            label_msgid="label_tagline",
            label="Tagline",
            description_msgid="help_tagline_movie",
            description="Enter the tagline of this movie.",
            size=40,
            i18n_domain="videotheque"
            )
        ),

    TextField(
        name="plot_summary",
        schemata="plot",
        searchable=True,
        widget=TextAreaWidget(
            label_msgid="label_plot_summary",
            label="Plot Summary",
            description_msgid="help_plot_summary_movie",
            description="Enter the plot summary of this movie.",
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="plot_keywords",
        schemata="plot",
        vocabulary="_getPlotKeywordOptions", enforceVocabulary=True,
        multiValued=True,
        accessor="PlotKeyword", edit_accessor="PlotKeyword",
        index="KeywordIndex",
        widget=KeywordWidget(
            label_msgid="label_plot_keywords",
            label="Plot Keywords",
            description_msgid="help_plot_keywords_movie",
            description="Select the plot keywords of this movie.",
            i18n_domain="videotheque"
            )
        ),

    ImageField(
        name="poster",
        widget=ImageWidget(
            label_msgid="label_poster",
            label="Poster",
            description_msgid="help_poster_movie",
            description="Upload the poster image of this movie.",
            i18n_domain="videotheque"
            )
        ),

    FloatField(
        name="imdb_rating",
        widget=DecimalWidget(
            label_msgid="label_imdb_rating",
            label="IMDB Rating",
            description_msgid="help_imdb_rating_movie",
            description="Enter the IMDB rating of this movie.",
            modes=("view",),
            maxlength=4, size=3,
            i18n_domain="videotheque"
            )
        ),

    LinesField(
        name="connected_movies",
        widget=LinesWidget(
            label_msgid="label_movies_connected",
            label="Connected Movies",
            description_msgid="help_movies_connected",
            description="Enter the IMDB ids of the connected movies, each one on a separate line.",
            i18n_domain="videotheque"
            )
        ),
    ),)

finalizeATCTSchema(MovieSchema)


class Movie(ATCTContent):
    """A movie."""

    __implements__ = (ATCTContent.__implements__,)

    schema = MovieSchema

    _at_rename_after_creation = True

    security = ClassSecurityInfo()

    security.declarePublic("_getColorOptions")
    def _getColorOptions(self):
        options = self.videotheque_tool.getOptions("color_options")
        return tuple(options)

    security.declarePublic("_getGenreOptions")
    def _getGenreOptions(self):
        options = self.videotheque_tool.getOptions("genre_options")
        return tuple(options)

    security.declarePublic("_getCountryOptions")
    def _getCountryOptions(self):
        options = self.videotheque_tool.getOptions("country_options")
        return tuple(options)

    security.declarePublic("_getLanguageOptions")
    def _getLanguageOptions(self):
        options = self.videotheque_tool.getOptions("language_options")
        return tuple(options)

    security.declarePublic("_getPlotKeywordOptions")
    def _getPlotKeywordOptions(self):
        options = self.videotheque_tool.getOptions("plot_keyword_options")
        return tuple(options)

    security.declarePublic("getConnectedMovies")
    def getConnectedMovies(self):
        parent = self.getParentNode()
        while parent.portal_type not in ("Plone Site", "Videotheque"):
            parent = parent.getParentNode()
        if parent.portal_type == "Plone Site":
            return []
        movies = [parent.getMovie(id) for id in self.connected_movies]
        return filter(lambda o: o is not None, movies)


registerATCT(Movie, PROJECTNAME)
