# -*- coding: utf-8 -*-
#
# Copyright (c) 2007 by H. Turgut Uyar <uyar@tekir.org>
#
# This file is part of Humphrey Videotheque.
#
# Humphrey Videotheque is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Humphrey Videotheque is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

__author__ = """H. Turgut Uyar <uyar@tekir.org>"""
__docformat__ = "restructuredtext"


from Products.Archetypes.atapi import Schema
from Products.Archetypes.atapi import StringField
from Products.Archetypes.atapi import LinesField
from Products.Archetypes.atapi import SelectionWidget
from Products.Archetypes.atapi import MultiSelectionWidget


SingleLanguageSchema = Schema((
    StringField(
        name="langs",
        schemata="language",
        vocabulary="_getLanguageOptions", enforceVocabulary=True,
        widget=SelectionWidget(
            label_msgid="label_languages",
            label="Languages",
            description_msgid="help_languages_copy_single",
            description="Select the dubbing language of this copy.",
            i18n_domain="videotheque"
            )
        ),
    ),)


MultipleLanguageSchema = Schema((
    LinesField(
        name="langs",
        schemata="language",
        vocabulary="_getLanguageOptions", enforceVocabulary=True,
        multiValued=True,
        widget=MultiSelectionWidget(
            label_msgid="label_languages",
            label="Languages",
            description_msgid="help_languages_copy_multiple",
            description="Select the dubbing language options of this copy.",
            i18n_domain="videotheque"
            )
        ),
    ),)


SingleSubtitleSchema = Schema((
    StringField(
        name="subtitles",
        schemata="language",
        vocabulary="_getLanguageOptions", enforceVocabulary=True,
        widget=SelectionWidget(
            label_msgid="label_subtitles",
            label="Subtitles",
            description_msgid="help_subtitles_copy_single",
            description="Select the subtitle language of this copy.",
            i18n_domain="videotheque"
            )
        ),
    ),)


MultipleSubtitleSchema = Schema((
    LinesField(
        name="subtitles",
        schemata="language",
        vocabulary="_getLanguageOptions", enforceVocabulary=True,
        multiValued=True,
        widget=MultiSelectionWidget(
            label_msgid="label_subtitles",
            label="Subtitles",
            description_msgid="help_subtitles_copy_multiple",
            description="Select the subtitle language options of this copy.",
            i18n_domain="videotheque"
            )
        ),
    ),)

TVSystemSchema = Schema((
    StringField(
        name="tv_system",
        vocabulary="_getTvSystemOptions", enforceVocabulary=True,
        widget=SelectionWidget(
            label_msgid="label_tv_system",
            label="TV System",
            description_msgid="help_tv_system_copy",
            description="Select the TV system of this copy.",
            i18n_domain="videotheque"
            )
        ),
     ),)
